translate.storage.subtitles

Package translate :: Package storage :: Module subtitles |
[hide private]
[frames] | no frames]

# Module subtitles

source code

Class that manages subtitle files for translation

This class makes use of the subtitle functionality of gaupol

See Also: gaupo/agents/open.py::open_main

a patch to gaupol is required to open utf-8 files successfully

Classes | [hide private]
| SubtitleUnit A subtitle entry that is translatable
| SubtitleFile A subtitle file
| SubRipFile specialized class for SubRipFile's only
| MicroDVDFile specialized class for SubRipFile's only
| AdvSubStationAlphaFile specialized class for SubRipFile's only
| SubStationAlphaFile specialized class for SubRipFile's only

Imports: StringIO, gaupol, base, MicroDVD, SubStationAlpha, AdvSubStationAlpha, SubRip, newlines